=========================
mythx_cli.version package
=========================

mythx_cli.version.command
-------------------------

.. automodule:: mythx_cli.version.command
    :members:
    :undoc-members:
    :show-inheritance:

    .. autofunction:: version
